BackendConnectionAsync

Trait BackendConnectionAsync 

pub trait BackendConnectionAsync:
    ConnectionMethodsAsync
    + Debug
    + Send {
    // Required methods
    fn transaction<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<TransactionAsync<'life0>, Error>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             Self: 'async_trait;
    fn backend(&self) -> Box<dyn Backend>;
    fn backend_name(&self) -> &'static str;
    fn is_closed(&self) -> bool;
}
Database connection.

Required Methods

fn transaction<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<TransactionAsync<'life0>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait, Self: 'async_trait,

Begin a database transaction. The transaction object must be used in place of this connection until it is committed or aborted.

fn backend(&self) -> Box<dyn Backend>

Retrieve the backend for this connection.

fn backend_name(&self) -> &'static str

Retrieve the backend name for this connection.

fn is_closed(&self) -> bool

Tests if the connection has been closed. Backends which do not support this check should return false.